@@ -2,4 +2,4 @@ from yt_dlp.postprocessor.common import PostProcessor
 
 
 class NormalPluginPP(PostProcessor):
-    pass
+    REPLACED = False
