@@ -11,16 +11,16 @@ from ..utils import (
     float_or_none,
     get_element_by_class,
     get_element_by_id,
-    int_or_none,
     parse_duration,
     qualities,
     str_to_int,
-    traverse_obj,
     try_get,
     unified_timestamp,
+    url_or_none,
     urlencode_postdata,
     urljoin,
 )
+from ..utils.traversal import traverse_obj
 
 
 class TwitCastingIE(InfoExtractor):
@@ -139,13 +139,7 @@ class TwitCastingIE(InfoExtractor):
             r'data-toggle="true"[^>]+datetime="([^"]+)"',
             webpage, 'datetime', None))
 
-        stream_server_data = self._download_json(
-            'https://twitcasting.tv/streamserver.php?target=%s&mode=client' % uploader_id, video_id,
-            'Downloading live info', fatal=False)
-
         is_live = any(f'data-{x}' in webpage for x in ['is-onlive="true"', 'live-type="live"', 'status="online"'])
-        if not traverse_obj(stream_server_data, 'llfmp4') and is_live:
-            self.raise_login_required(method='cookies')
 
         base_dict = {
             'title': title,
@@ -166,31 +160,40 @@ class TwitCastingIE(InfoExtractor):
                 return [data_movie_url]
 
         m3u8_urls = (try_get(webpage, find_dmu, list)
-                     or traverse_obj(video_js_data, (..., 'source', 'url'))
-                     or ([f'https://twitcasting.tv/{uploader_id}/metastream.m3u8'] if is_live else None))
-        if not m3u8_urls:
-            raise ExtractorError('Failed to get m3u8 playlist')
+                     or traverse_obj(video_js_data, (..., 'source', 'url')))
 
         if is_live:
-            m3u8_url = m3u8_urls[0]
-            formats = self._extract_m3u8_formats(
-                m3u8_url, video_id, ext='mp4', m3u8_id='hls',
-                live=True, headers=self._M3U8_HEADERS)
+            stream_data = self._download_json(
+                'https://twitcasting.tv/streamserver.php',
+                video_id, 'Downloading live info', query={
+                    'target': uploader_id,
+                    'mode': 'client',
+                    'player': 'pc_web',
+                })
 
-            if traverse_obj(stream_server_data, ('hls', 'source')):
-                formats.extend(self._extract_m3u8_formats(
-                    m3u8_url, video_id, ext='mp4', m3u8_id='source',
-                    live=True, query={'mode': 'source'},
-                    note='Downloading source quality m3u8',
-                    headers=self._M3U8_HEADERS, fatal=False))
+            formats = []
+            # low: 640x360, medium: 1280x720, high: 1920x1080
+            qq = qualities(['low', 'medium', 'high'])
+            for quality, m3u8_url in traverse_obj(stream_data, (
+                'tc-hls', 'streams', {dict.items}, lambda _, v: url_or_none(v[1]),
+            )):
+                formats.append({
+                    'url': m3u8_url,
+                    'format_id': f'hls-{quality}',
+                    'ext': 'mp4',
+                    'quality': qq(quality),
+                    'protocol': 'm3u8',
+                    'http_headers': self._M3U8_HEADERS,
+                })
 
             if websockets:
                 qq = qualities(['base', 'mobilesource', 'main'])
-                streams = traverse_obj(stream_server_data, ('llfmp4', 'streams')) or {}
-                for mode, ws_url in streams.items():
+                for mode, ws_url in traverse_obj(stream_data, (
+                    'llfmp4', 'streams', {dict.items}, lambda _, v: url_or_none(v[1]),
+                )):
                     formats.append({
                         'url': ws_url,
-                        'format_id': 'ws-%s' % mode,
+                        'format_id': f'ws-{mode}',
                         'ext': 'mp4',
                         'quality': qq(mode),
                         'source_preference': -10,
@@ -198,10 +201,15 @@ class TwitCastingIE(InfoExtractor):
                         'protocol': 'websocket_frag',
                     })
 
+            if not formats:
+                self.raise_login_required()
+
             infodict = {
                 'formats': formats,
                 '_format_sort_fields': ('source', ),
             }
+        elif not m3u8_urls:
+            raise ExtractorError('Failed to get m3u8 playlist')
         elif len(m3u8_urls) == 1:
             formats = self._extract_m3u8_formats(
                 m3u8_urls[0], video_id, 'mp4', headers=self._M3U8_HEADERS)
@@ -242,40 +250,36 @@ class TwitCastingLiveIE(InfoExtractor):
         'expected_exception': 'UserNotLive',
     }]
 
-    _PROTECTED_LIVE_RE = r'(?s)(<span\s*class="tw-movie-thumbnail2-badge"\s*data-status="live">\s*LIVE)'
-
     def _real_extract(self, url):
         uploader_id = self._match_id(url)
         self.to_screen(
-            'Downloading live video of user {0}. '
-            'Pass "https://twitcasting.tv/{0}/show" to download the history'.format(uploader_id))
+            f'Downloading live video of user {uploader_id}. '
+            f'Pass "https://twitcasting.tv/{uploader_id}/show" to download the history')
 
-        webpage = self._download_webpage(url, uploader_id)
-        is_live = self._search_regex(  # first pattern is for public live
-            (r'(data-is-onlive="true")', self._PROTECTED_LIVE_RE), webpage, 'is live?', default=None)
-        current_live = int_or_none(self._search_regex(
-            (r'data-type="movie" data-id="(\d+)">',  # not available?
-             r'tw-sound-flag-open-link" data-id="(\d+)" style=',  # not available?
-             r'data-movie-id="(\d+)"'),  # if not currently live, value may be 0
-            webpage, 'current live ID', default=None))
-        if is_live and not current_live:
-            # fetch unfiltered /show to find running livestreams; we can't get ID of the password-protected livestream above
-            webpage = self._download_webpage(
-                f'https://twitcasting.tv/{uploader_id}/show/', uploader_id,
-                note='Downloading live history')
-            is_live = self._search_regex(self._PROTECTED_LIVE_RE, webpage, 'is live?', default=None)
-            if is_live:
-                # get the first live; running live is always at the first
-                current_live = self._search_regex(
-                    r'(?s)<a\s+class="tw-movie-thumbnail2"\s*href="/[^/]+/movie/(?P<video_id>\d+)"\s*>.+?</a>',
-                    webpage, 'current live ID 2', default=None, group='video_id')
-        if not current_live:
+        is_live = traverse_obj(self._download_json(
+            f'https://frontendapi.twitcasting.tv/watch/user/{uploader_id}',
+            uploader_id, 'Checking live status', data=b'', fatal=False), ('is_live', {bool}))
+        if is_live is False:  # only raise here if API response was as expected
             raise UserNotLive(video_id=uploader_id)
+
+        # Use /show/ page so that password-protected and members-only livestreams can be found
+        webpage = self._download_webpage(
+            f'https://twitcasting.tv/{uploader_id}/show/', uploader_id, 'Downloading live history')
+        is_live = is_live or self._search_regex(
+            r'(?s)(<span\s*class="tw-movie-thumbnail2-badge"\s*data-status="live">\s*LIVE)',
+            webpage, 'is live?', default=False)
+        # Current live is always the first match
+        current_live = self._search_regex(
+            r'(?s)<a\s+class="tw-movie-thumbnail2"\s+href="/[^/"]+/movie/(?P<video_id>\d+)"',
+            webpage, 'current live ID', default=None, group='video_id')
+        if not is_live or not current_live:
+            raise UserNotLive(video_id=uploader_id)
+
         return self.url_result(f'https://twitcasting.tv/{uploader_id}/movie/{current_live}', TwitCastingIE)
 
 
 class TwitCastingUserIE(InfoExtractor):
-    _VALID_URL = r'https?://(?:[^/?#]+\.)?twitcasting\.tv/(?P<id>[^/?#]+)/(:?show|archive)/?(?:[#?]|$)'
+    _VALID_URL = r'https?://(?:[^/?#]+\.)?twitcasting\.tv/(?P<id>[^/?#]+)/(?:show|archive)/?(?:[#?]|$)'
     _TESTS = [{
         'url': 'https://twitcasting.tv/natsuiromatsuri/archive/',
         'info_dict': {
@@ -289,13 +293,12 @@ class TwitCastingUserIE(InfoExtractor):
     }]
 
     def _entries(self, uploader_id):
-        base_url = next_url = 'https://twitcasting.tv/%s/show' % uploader_id
+        base_url = next_url = f'https://twitcasting.tv/{uploader_id}/show'
         for page_num in itertools.count(1):
             webpage = self._download_webpage(
-                next_url, uploader_id, query={'filter': 'watchable'}, note='Downloading page %d' % page_num)
+                next_url, uploader_id, query={'filter': 'watchable'}, note=f'Downloading page {page_num}')
             matches = re.finditer(
-                r'''(?isx)<a\s+class="tw-movie-thumbnail"\s*href="(?P<url>/[^/]+/movie/\d+)"\s*>.+?</a>''',
-                webpage)
+                r'(?s)<a\s+class="tw-movie-thumbnail2"\s+href="(?P<url>/[^/"]+/movie/\d+)"', webpage)
             for mobj in matches:
                 yield self.url_result(urljoin(base_url, mobj.group('url')))
 
@@ -309,4 +312,4 @@ class TwitCastingUserIE(InfoExtractor):
     def _real_extract(self, url):
         uploader_id = self._match_id(url)
         return self.playlist_result(
-            self._entries(uploader_id), uploader_id, '%s - Live History' % uploader_id)
+            self._entries(uploader_id), uploader_id, f'{uploader_id} - Live History')
